library(gnlm)
library(repeated)
library(growth)

data <- as.matrix(read.table("audiomet.dat",skip=8,head=T))
freq <- c(250,500,1000,2000,4000)

y <- restovec(data,times=freq,delta=0.1)
nest <- gl(36,5,180)
fr <- matrix(rep(freq,36),ncol=5,byrow=T)
source <- as.factor(c(rep(1,9),rep(2,11),rep(3,8),rep(4,8)))
reps <- rmna(y,tvc=tvctomat(fr),ccov=tcctomat(~source))

if(interactive()){
postscript("audiopr.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(y,,ylim=c(-20,25),xlim=c(0,4000),ylab="Error",xlab="Frequency",
	xaxt="n",lty=1)
axis(1,c(0,250,500,1000,2000,4000))
dev.off()
}

mu1 <- ~b0+exp(b1*fr)
gnlr(reps,"normal",mu=mu1,pmu=c(-4,0.001),psh=6)
gnlr(reps,"logistic",mu=mu1,pmu=c(-3.54,0.00032),psh=1.1)
gnlr(reps,"Cauchy",mu=mu1,pmu=c(-3.6,0.0003),psh=0.6)
gnlr(reps,"Cauchy",mu=~fr,pmu=c(-1.5,0.01),psh=1)

gnlmm(reps,"normal",mu=mu1,pmu=c(-3.3,0.0003),psh=2.7,psd=2,nest=nest,points=7)
gnlmm(reps,"logistic",mu=mu1,pmu=c(-3.4,0.0003),psh=0.8,psd=2,nest=nest,
	points=7)
gnlmm(reps,"Cauchy",mu=mu1,pmu=c(-3.7,0.0003),psh=0.44,psd=1.6,nest=nest,
	points=7)
gnlmm(reps,"Cauchy",mu=~fr,pmu=c(-2.3,0.0005),psh=-0.3,psd=1.5,nest=nest,
	points=7)

gar(reps,"normal",mu=mu1,preg=c(-3,0.00047),psh=4,pdep=0.99)
gar(reps,"logistic",mu=mu1,preg=c(-3,0.00047),psh=1,pdep=0.99)
print(zgc <- gar(reps,"Cauchy",mu=mu1,preg=c(-3,0.00047),psh=0.3,pdep=0.99))

if(interactive()){
postscript("audioipr.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(mprofile(zgc),ylim=c(-20,25),xlim=c(0,4000),ylab="Error",xlab="Frequency",
	xaxt="n")
axis(1,c(0,250,500,1000,2000,4000))
plot(iprofile(zgc),lty=3,add=T)
plot(iprofile(zgc),nin=23,lty=2,pch=2,add=T)
plot(iprofile(zgc),nin=25,lty=4,pch=1,add=T)
dev.off()
}

print(zn <- elliptic(reps,model=mu1,preg=c(-2.4,0.0006),pvar=15.5))
print(znar <- elliptic(reps,model=mu1,preg=c(-2.4,0.0006),pvar=15,par=0.999))
print(znre <- elliptic(reps,model=mu1,preg=c(-2.4,0.0006),pvar=15,pre=1))
print(znare <- elliptic(reps,model=mu1,preg=c(-3.3,0.0003),pvar=10,pre=5.8,
	par=0.99))
print(znres <- elliptic(reps,model=mu1,preg=c(-2.4,0.0006),pvar=c(15,0,0,0),
	pre=1,varfn=~source2+source3+source4))

print(zel <- elliptic(reps,model=mu1,preg=c(-3,0.0006),pvar=0.000001,
	dist="power exp",pell=0.175))
print(zelar <- elliptic(reps,model=mu1,preg=c(-3.3,0.0003),pvar=0.00001,
	dist="power exp",pell=0.2,par=0.998))
print(zelre <- elliptic(reps,model=mu1,preg=c(-3.3,0.0003),pvar=9.8,
	dist="power exp",pell=1,pre=5.6))
print(zelare <- elliptic(reps,model=mu1,preg=c(-3.32,0.00027),pvar=0.0000001,
	dist="power exp",pell=0.18,pre=0.00000008,par=0.999))
print(zelres <- elliptic(reps,model=mu1,preg=c(-3.3,0.0003),dist="power exp",
	pell=1,pvar=c(9.8,0,0,0),pre=5.6,varfn=~source2+source3+source4))
