library(gnlm)
library(repeated)
library(growth)

data <- as.matrix(read.table("audiomet.dat",skip=8,head=T))
freq <- c(250,500,1000,2000,4000)

if(interactive()){
postscript("audiopr.eps",width=5,height=5)
plot(freq,data[1,],type="l",ylim=c(-20,25),xlim=c(0,4000),ylab="Error",
	xlab="Frequency")
for (i in 2:36)lines(freq,data[i,])
}

y <- restovec(data,times=freq,delta=0.1)
source <- as.factor(c(rep(1,9*5),rep(2,11*5),rep(3,8*5),rep(4,8*5)))
nest <- gl(36,5,180)
fr <- rep(freq,36)

mu1 <- function(p) p[1]+exp(p[2]*fr)
mu2 <- function(p) p[1]+p[3]*exp(p[2]*fr)
mu3 <- function(p) p[1]+exp(p[2]*fr)+p[3]*(source==2)+
	p[4]*(source==3)+p[5]*(source==4)
gnlr(y,"normal",pmu=-1.5,psh=3)
gnlr(y,"normal",mu=~source,pmu=c(-1.5,0,0,0),psh=3)
gnlr(y,"normal",mu=~fr,pmu=c(-1.5,0.01),psh=3)
gnlr(y,"normal",mu=mu1,pmu=c(-4,0.001),psh=6)
gnlr(y,"logistic",pmu=-1.5,psh=1)
gnlr(y,"logistic",mu=~fr,pmu=c(-1.5,0.01),psh=1)
gnlr(y,"logistic",mu=mu1,pmu=c(-3.54,0.00032),psh=1.1)
gnlr(y,"Cauchy",pmu=-1.5,psh=1)
gnlr(y,"Cauchy",mu=~source,pmu=c(-1.5,0,0,0),psh=1)
gnlr(y,"Cauchy",mu=~fr,pmu=c(-1.5,0.01),psh=1)
gnlr(y,"Cauchy",mu=mu1,pmu=c(-3.6,0.0003),psh=0.6)
gnlr(y,"Cauchy",mu=mu2,pmu=c(-2.33,0.001,0.042),psh=0.59)
gnlr(y,"Cauchy",mu=mu1,pmu=c(-3,0.00047),shape=~fr,psh=c(0.6,0))

yy <- response(y)
summary(glmm(yy~fr,nest=nest,points=3))
gnlmm(y,"normal",pmu=-1.5,psh=3,psd=1,nest=nest,points=3)
gnlmm(y,"normal",mu=~fr,pmu=c(-2.4,0.0005),psh=3,psd=1,nest=nest,points=3)
gnlmm(y,"normal",mu=mu1,pmu=c(-3.3,0.0003),psh=2.7,psd=2,nest=nest,points=7)
gnlmm(y,"logistic",pmu=-1.5,psh=1,psd=1,nest=nest,points=3)
gnlmm(y,"logistic",mu=mu1,pmu=c(-3.4,0.0003),psh=0.8,psd=2,nest=nest,points=7)
gnlmm(y,"Cauchy",pmu=-1.5,psh=1,psd=1,nest=nest,points=3)
gnlmm(y,"Cauchy",mu=~fr,pmu=c(-2.3,0.0005),psh=-0.3,psd=1.5,nest=nest,points=7)
gnlmm(y,"Cauchy",mu=mu1,pmu=c(-3.7,0.0003),psh=0.44,psd=1.6,nest=nest,points=7)

gar(y,"normal",mu=mu1,preg=c(-3,0.00047),psh=3,pdep=0.99)
gar(y,"logistic",mu=mu1,preg=c(-3,0.00047),psh=1,pdep=0.99)
print(zgc <- gar(y,"Cauchy",mu=mu1,preg=c(-3,0.00047),psh=0.3,pdep=0.99))
print(zgct <- gar(y,"Cauchy",mu=mu3,preg=c(-3,0.00047,0,0,0),psh=0.3,
	pdep=0.99))

if(interactive()){
postscript("audioipr.eps",width=5,height=5)
plot(mprofile(zgc),ylim=c(-20,25),xlim=c(0,4000),ylab="Error",xlab="Frequency")
plot(iprofile(zgc),lty=3,add=T)
plot(iprofile(zgc),nin=23,lty=2,pch=2,add=T)
plot(iprofile(zgc),nin=25,lty="4212",pch=1,add=T)
}

source <- c(rep(1,9*5),rep(2,11*5),rep(3,8*5),rep(4,8*5))
shape <- function(p) p[1]+(source==2)*p[2]+(source==3)*p[3]+(source==4)*p[4]
print(zn <- elliptic(y,model=mu1,preg=c(-2.4,0.0006),pvar=15.5))
print(znar <- elliptic(y,model=mu1,preg=c(-2.4,0.0006),pvar=15,par=0.999))
print(znre <- elliptic(y,model=mu1,preg=c(-2.4,0.0006),pvar=15,pre=1))
print(znare <- elliptic(y,model=mu1,preg=c(-3.3,0.0003),pvar=10,pre=5.8,
	par=0.99))
print(znres <- elliptic(y,model=mu1,preg=c(-2.4,0.0006),pvar=c(15,0,0,0),
	pre=1,varfn=shape))
print(zel <- elliptic(y,model=mu1,preg=c(-3,0.0006),pvar=0.000001,pell=0.175))
print(zelar <- elliptic(y,model=mu1,preg=c(-3.3,0.0003),pvar=0.00001,pell=0.2,
	par=0.998))
print(zelre <- elliptic(y,model=mu1,preg=c(-3.3,0.0003),pvar=9.8,pell=1,
	pre=5.6))
print(zelare <- elliptic(y,model=mu1,preg=c(-3.32,0.00027),pvar=0.0000001,
	pell=0.18,pre=0.00000008,par=0.999))
print(zelre3 <- elliptic(y,model=mu3,preg=c(-3.3,0.0003,0,0,0),pvar=9.8,pell=1,
	pre=5.6))
print(zelres <- elliptic(y,model=mu1,preg=c(-3.3,0.0003),pell=1,
	pvar=c(9.8,0,0,0),pre=5.6,varfn=shape))
