library(growth)
library(repeated)
library(gnlm)

data <- read.table("lutein2.dat",skip=4)
times <- c(1,2,3,4,5,5.5,6,6.5,7,7.5,8,8.5,9,9.5,10)
suck <- c(rep(0,240),rep(1,240))
resp <- restovec(data,times=times)
resp1 <- restovec(data[1:16,],times=times)
resp2 <- restovec(data[17:32,],times=times)
lresp <- restovec(log(data),times=times,delta=1/data)
lresp1 <- restovec(log(data[1:16,]),times=times,delta=1/data[1:16,])
lresp2 <- restovec(log(data[17:32,]),times=times,delta=1/data[17:32,])

if(interactive()){
postscript("lutpr2.eps",height=5)
par(mfrow=c(1,2),font.main=1)
plot(resp,nind=1:16,lty=1,xlab="Days",ylab="Luteinizing hormone (1000 ng/ml)",
	main="Non-suckled cows")
plot(resp,nind=17:32,lty=1,xlab="Days",ylab="",main="Suckled cows")
}

elliptic(resp,pvar=160000)
elliptic(resp,pvar=160000,par=0.5)
elliptic(resp,pvar=30000,par=0.2,auto="IOU")
elliptic(resp,pvar=160000,pre=15000)
elliptic(resp,pvar=160000,pell=1)
elliptic(resp,pvar=160000,par=0.5,pell=1)
elliptic(resp,pvar=160000,pre=15000,pell=1)

mu <- function(p) array(rep(p[1:2],rep(32,2)),c(32,2))
mu1 <- function(p) array(rep(p[1:2],rep(16,2)),c(16,2))
mu2 <- function(p) array(c(rep(p[c(1,3)],rep(16,2)),rep(p[c(2,4)],rep(16,2))),
	c(32,2))
gnlr(resp,dist="normal",pmu=700,psh=13)
gnlr(resp,dist="normal",pmu=c(700,-230),psh=13,mu=~suck)
print(z <- chidden(resp,dist="normal",cmu=mu,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=90000))
print(z <- chidden(resp,dist="normal",pcmu=c(700,2500,200,500),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=90000))
gnlr(lresp,dist="normal",pmu=6,psh=0)
gnlr(lresp,dist="normal",pmu=c(6,-1),psh=0,mu=~suck)
print(z <- chidden(lresp,dist="normal",cmu=mu,pcmu=c(6,8),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.2))
print(z <- chidden(lresp,dist="normal",cmu=mu,pcmu=c(6,7),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.1,0.2)))
print(z <- chidden(lresp,dist="normal",pcmu=c(6,7,4,6),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.2))
print(z <- chidden(lresp,dist="normal",pcmu=c(5.8,6.4,5.8,6.4),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.05,0.17)))
print(z <- chidden(lresp1,dist="normal",pcmu=c(6,6.7),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.1,0.2)))
print(z <- chidden(lresp2,dist="normal",pcmu=c(5.8,6.3),
	cmu=mu1,pgamma=matrix(c(-0.1,0.2,0.1,-0.2),ncol=2),psh=c(0.1,0.2)))
gnlr(resp,dist="gamma",pmu=700,psh=1)
gnlr(resp,dist="gamma",pmu=c(700,-230),psh=1,mu=~suck)
print(z <- chidden(resp,dist="gamma",cmu=mu,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=4))
print(z <- chidden(resp,dist="gamma",cmu=mu,pcmu=c(500,1400),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(8,4)))
print(z <- chidden(resp,dist="gamma",pcmu=c(700,2500,200,500),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=4))
print(z <- chidden(resp,dist="gamma",pcmu=c(500,1400,200,500),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(8,4)))
print(z <- chidden(resp1,dist="gamma",pcmu=c(500,1400),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(8,4)))
print(z <- chidden(resp2,dist="gamma",pcmu=c(300,600),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(8,4)))
gnlr(resp,dist="Weibull",pmu=700,psh=1)
gnlr(resp,dist="Weibull",pmu=c(700,-230),psh=1,mu=~suck)
print(z <- chidden(resp,dist="Weibull",cmu=mu,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1))
print(z <- chidden(resp,dist="Weibull",cmu=mu,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(4,1)))
print(z <- chidden(resp,dist="Weibull",pcmu=c(700,2500,200,500),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1))
print(z <- chidden(resp,dist="Weibull",pcmu=c(700,2500,200,500),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(4,1)))
print(z <- chidden(resp1,dist="Weibull",pcmu=c(700,2500),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(4,1)))
print(z <- chidden(resp2,dist="Weibull",pcmu=c(500,800),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(4,1)))
gnlr(resp,dist="inverse Gauss",pmu=700,psh=-5)
gnlr(resp,dist="inverse Gauss",pmu=c(700,-230),psh=1,mu=~suck)
gnlr(resp2,dist="inverse Gauss",pmu=700,psh=-5)
print(z <- chidden(resp,dist="inverse Gau",cmu=mu,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.0002))
print(z <- chidden(resp,dist="inverse Gau",cmu=mu,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.0002,0.0002)))
print(z <- chidden(resp,dist="inverse Gau",pcmu=c(700,2500,200,500),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.0002))
print(z <- chidden(resp,dist="inverse Gau",pcmu=c(700,2500,200,500),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.0002,0.0002)))
print(z <- chidden(resp1,dist="inverse Gau",cmu=mu1,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.0002,0.0002)))
print(z <- chidden(resp2,dist="inverse Gau",cmu=mu1,pcmu=c(300,600),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.0002,0.0002)))
gnlr(resp,dist="Pareto",pmu=700,psh=8)
gnlr(resp,dist="Pareto",pmu=c(700,-230),psh=8,mu=~suck)
print(z <- chidden(resp,dist="Pareto",cmu=mu,pcmu=c(700,1000),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1000))
print(z <- chidden(resp,dist="Pareto",cmu=mu,pcmu=c(700,800),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(1000,2000)))
#print(z <- chidden(resp,dist="Levy",cmu=mu,pcmu=c(230,240),
#	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(100,500)))
gnlr3(resp,dist="gamma",pmu=0.0001,psh=4.3,pfam=-1.4)
gnlr3(resp,dist="gamma",pmu=c(0.0001,0),psh=4.3,pfam=-1.4,mu=~suck)
print(z <- chidden(resp,dist="gen gamma",cmu=mu,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
print(z <- chidden(resp,dist="gen gamma",pcmu=c(700,2500,200,500),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
gnlr3(resp,dist="Weibull",pmu=0.021,psh=-1.4,pfam=11,iter=200)
gnlr3(resp,dist="Weibull",pmu=c(0.02,0),psh=-1,pfam=10,iter=200,mu=~suck)
print(z <- chidden(resp,dist="gen Weibull",cmu=mu,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
print(z <- chidden(resp,dist="gen Weibull",
	pcmu=c(700,2500,200,500),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
gnlr3(resp,dist="inverse Gauss",pmu=3,psh=2,pfam=4.2)
gnlr3(resp,dist="inverse Gauss",pmu=c(3,-0.5),psh=2,pfam=4.9,mu=~suck)
print(z <- chidden(resp,dist="gen inverse",cmu=mu,pcmu=c(7,25),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
print(z <- chidden(resp,dist="gen inverse",pcmu=c(7,25,2,5),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=0.4,pfam=2))
gnlr3(resp,dist="Burr",pmu=700,psh=1,pfam=1)
gnlr3(resp,dist="Burr",pmu=c(700,-230),psh=1,pfam=1,mu=~suck)
gnlr3(resp2,dist="Burr",pmu=700,psh=1,pfam=1)
print(z <- chidden(resp,dist="Burr",cmu=mu,pcmu=c(300,450),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
print(z <- chidden(resp,dist="Burr",pcmu=c(300,450,100,250),
	cmu=mu2,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
print(z1 <- chidden(resp1,dist="Burr",pcmu=c(300,450),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
mexp(z1$gamma)
print(z2 <- chidden(resp2,dist="Burr",pcmu=c(300,450),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
mexp(z2$gamma)
#print(z <- chidden(resp,dist="Hjorth",cmu=mu,pcmu=c(700,2500),
#	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))

if(interactive()){
postscript("luthm2.eps")
par(mfrow=c(4,4),font.main=1)
plot(times,z1$filt[1,covind(z1)==1],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 1",ylim=c(0,1))
for(i in 2:4)
plot(times,z1$filt[1,covind(z1)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i),ylim=c(0,1))
plot(times,z1$filt[1,covind(z1)==5],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 5",ylim=c(0,1))
for(i in 6:8)
plot(times,z1$filt[1,covind(z1)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i),ylim=c(0,1))
plot(times,z2$filt[1,covind(z2)==1],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 17",ylim=c(0,1))
for(i in 2:4)
plot(times,z2$filt[1,covind(z2)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i+16),ylim=c(0,1))
plot(times,z2$filt[1,covind(z2)==5],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 21",ylim=c(0,1))
for(i in 6:8)
plot(times,z2$filt[1,covind(z2)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i+16),ylim=c(0,1))
}
