library(growth)
library(repeated)
library(gnlm)

data <- read.table("lutein2.dat",skip=4)
times <- c(1,2,3,4,5,5.5,6,6.5,7,7.5,8,8.5,9,9.5,10)
suck <- c(rep(0,240),rep(1,240))
resp <- restovec(data,times=times)
resp1 <- restovec(data[1:16,],times=times)
resp2 <- restovec(data[17:32,],times=times)
lresp <- restovec(log(data),times=times,delta=1/data)
lresp1 <- restovec(log(data[1:16,]),times=times,delta=1/data[1:16,])
lresp2 <- restovec(log(data[17:32,]),times=times,delta=1/data[17:32,])

if(interactive()){
postscript("lutpr2.eps",height=5)
par(mfrow=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(resp,nind=1:16,lty=1,xlab="Days",ylab="Luteinizing hormone (1000 ng/ml)",
	main="Non-suckled cows",xlim=c(0,10),yaxt="n")
axis(2,c(0,1000,2000,4000,6000))
plot(resp,nind=17:32,lty=1,xlab="Days",ylab="",main="Suckled cows",
	xlim=c(0,10),yaxt="n")
axis(2,c(0,1000,2000,4000,6000))
dev.off()
}

gnlr(lresp,dist="normal",pmu=c(6,-1),psh=0,mu=~suck)
gnlr(resp,dist="gamma",pmu=c(700,-230),psh=1,mu=~suck)
gnlr(resp,dist="Weibull",pmu=c(700,-230),psh=1,mu=~suck)
gnlr(resp,dist="inverse Gauss",pmu=c(700,-230),psh=1,mu=~suck)
gnlr3(resp,dist="Burr",pmu=c(700,-230),psh=1,pfam=1,mu=~suck)

mu1 <- ~1
mu2 <- ~c(rep(a,16),rep(b,16))
print(z <- chidden(lresp,dist="normal",pcmu=c(6,6.3,6.7,5.9),cmu=mu2,
	pgamma=matrix(c(-0.12,0.13,0.12,-0.13),ncol=2),psh=c(0.05,0.17)))
print(z <- chidden(resp,dist="gamma",pcmu=c(950,550,450,325),
	cmu=mu2,pgamma=matrix(c(-0.15,0.16,0.15,-0.16),ncol=2),psh=c(4,8)))
print(z <- chidden(resp,dist="Weibull",pcmu=c(600,500,1400,700),
	cmu=mu2,pgamma=matrix(c(-0.15,0.16,0.15,-0.16),ncol=2),psh=c(4,1)))
print(z <- chidden(resp,dist="inverse Gauss",pcmu=c(900,600,500,300),
	cmu=mu2,pgamma=matrix(c(-0.15,0.16,0.15,-0.16),ncol=2),
	psh=c(0.0002,0.0002)))
print(z <- chidden(resp,dist="Burr",pcmu=c(600,500,400,300),cmu=mu2,
	pgamma=matrix(c(-0.11,0.1,0.11,-0.1),ncol=2),psh=10,pfam=0.4))

print(z <- chidden(lresp1,dist="normal",pcmu=c(6,6.7),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.1,0.2)))
print(z <- chidden(lresp2,dist="normal",pcmu=c(5.8,6.3),
	cmu=mu1,pgamma=matrix(c(-0.1,0.2,0.1,-0.2),ncol=2),psh=c(0.1,0.2)))
print(z <- chidden(resp1,dist="gamma",pcmu=c(500,1400),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(8,4)))
print(z <- chidden(resp2,dist="gamma",pcmu=c(300,600),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(8,4)))
print(z <- chidden(resp1,dist="Weibull",pcmu=c(700,2500),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(4,1)))
print(z <- chidden(resp2,dist="Weibull",pcmu=c(500,800),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(4,1)))
print(z <- chidden(resp1,dist="inverse Gau",cmu=mu1,pcmu=c(700,2500),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.0002,0.0002)))
print(z <- chidden(resp2,dist="inverse Gau",cmu=mu1,pcmu=c(300,600),
	pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=c(0.0001,0.0001)))
print(z1 <- chidden(resp1,dist="Burr",pcmu=c(300,450),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
mexp(z1$gamma)
print(z2 <- chidden(resp2,dist="Burr",pcmu=c(300,450),
	cmu=mu1,pgamma=matrix(c(-0.5,2,0.5,-2),ncol=2),psh=1,pfam=1))
mexp(z2$gamma)

if(interactive()){
postscript("luthm2.eps",width=5,height=7)
par(mfrow=c(4,4),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(times,z1$filt[2,covind(z1)==1],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 1",xlim=c(0,10),ylim=c(0,1))
for(i in 2:4)
plot(times,z1$filt[2,covind(z1)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i),xlim=c(0,10),ylim=c(0,1))
plot(times,z1$filt[2,covind(z1)==5],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 5",xlim=c(0,10),ylim=c(0,1))
for(i in 6:8)
plot(times,z1$filt[2,covind(z1)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i),xlim=c(0,10),ylim=c(0,1))
plot(times,z2$filt[1,covind(z2)==1],type="l",xlab="",ylab=expression(pi[2]),
	main="Cow 17",xlim=c(0,10),ylim=c(0,1))
for(i in 2:4)
plot(times,z2$filt[1,covind(z2)==i],type="l",xlab="",ylab="",
	main=paste("Cow ",i+16),xlim=c(0,10),ylim=c(0,1))
plot(times,z2$filt[1,covind(z2)==5],type="l",xlab="Days",
	ylab=expression(pi[2]),main="Cow 21",xlim=c(0,10),ylim=c(0,1))
for(i in 6:8)
plot(times,z2$filt[1,covind(z2)==i],type="l",xlab="Days",ylab="",
	main=paste("Cow ",i+16),xlim=c(0,10),ylim=c(0,1))
dev.off()
}
