library(gnlm)
library(repeated)

resp <- restovec(read.table("plasmaci.dat",skip=2),times=8:21)
cos1 <- rep(cos(2*pi*(8:21)/24),10)
sin1 <- rep(sin(2*pi*(8:21)/24),10)
cos2 <- rep(cos(2*pi*(8:21)/12),10)
sin2 <- rep(sin(2*pi*(8:21)/12),10)
tvc2 <- list()
for(i in 1:10)tvc2 <- c(tvc2,list(cbind(cos(2*pi*(8:21)/24),
	sin(2*pi*(8:21)/24),cos(2*pi*(8:21)/12),sin(2*pi*(8:21)/12))))
reps <- rmna(resp,tvc=tvctomat(tvc2,names=c("cos1","sin1","cos2","sin2")))

mu <- function(p,linear) exp(linear)
gnlr(reps,"Weibull",mu=~exp(a),pmu=5,psh=3)
gnlr(reps,"Weibull",mu=mu,linear=~cos1+sin1+cos2+sin2,pmu=c(5,0,0,0,0),psh=3.6)

kalseries(reps,intensity="Weibull",preg=4.7,pinit=1,psh=1,link="log")
kalseries(reps,intensity="Weibull",preg=4.5,pinit=1,psh=1,link="log",
	tvcov=~cos1+sin1+cos2+sin2,ptvc=c(0.02,0.3,0.2,0.08))

kalseries(reps,intensity="Weibull",preg=4.7,pinit=1,psh=1,link="log",
	dep="frailty")
kalseries(reps,intensity="Weibull",preg=4.5,pinit=1,psh=1,link="log",
	dep="frailty",tvcov=~cos1+sin1+cos2+sin2,ptvc=c(0.02,0.3,0.2,0.08))

kalseries(reps,intensity="Weibull",preg=4.7,pinit=1,psh=1,link="log",
	dep="serial",pdep=0.5)
print(z <- kalseries(reps,intensity="Weibull",preg=4.5,pinit=2,
	psh=1,link="log",dep="serial",pdep=0.6,
	tvcov=~cos1+sin1+cos2+sin2,ptvc=c(0.02,0.3,0.2,0.08)))

if(interactive()){
postscript("plasma.eps",width=5,height=7)
par(mfrow=c(3,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(mprofile(z),ylim=c(0,200),ylab="Plasma citrate concentration",
	xlab="Hour",main="Individuals 1 and 2")
plot(iprofile(z),add=T,lty=2,pch=0)
plot(iprofile(z),add=T,lty=3,pch=1,nind=2)
plot(mprofile(z),ylim=c(0,200),ylab="",xlab="Hour",
	main="Individuals 3 and 4")
plot(iprofile(z),add=T,lty=2,pch=0,nind=3)
plot(iprofile(z),add=T,lty=3,pch=1,nind=4)
plot(mprofile(z),ylim=c(0,200),ylab="Plasma citrate concentration",
	xlab="Hour",main="Individuals 5 and 6")
plot(iprofile(z),add=T,lty=2,pch=0,nind=5)
plot(iprofile(z),add=T,lty=3,pch=1,nind=6)
plot(mprofile(z),ylim=c(0,200),ylab="",xlab="Hour",
	main="Individuals 7 and 8")
plot(iprofile(z),add=T,lty=2,pch=0,nind=7)
plot(iprofile(z),add=T,lty=3,pch=1,nind=8)
plot(mprofile(z),ylim=c(0,200),ylab="Plasma citrate concentration",
	xlab="Hour",main="Individuals 9 and 10")
plot(iprofile(z),add=T,lty=2,pch=0,nind=9)
plot(iprofile(z),add=T,lty=3,pch=1,nind=10)
dev.off()
}
