library(gnlm)
library(repeated)

resp <- restovec(read.table("plasmaci.dat",skip=2),times=8:21)
id <- gl(10,14,140)
trend <- rep(1:14,10)
cos1 <- rep(cos(2*pi*(8:21)/24),10)
sin1 <- rep(sin(2*pi*(8:21)/24),10)
cos2 <- rep(cos(2*pi*(8:21)/12),10)
sin2 <- rep(sin(2*pi*(8:21)/12),10)
tvc2 <- list()
for(i in 1:10){
	tvc2 <- c(tvc2,list(cbind(cos(2*pi*(8:21)/24),
	sin(2*pi*(8:21)/24),cos(2*pi*(8:21)/12),sin(2*pi*(8:21)/12))))
	colnames(tvc2[[i]]) <- c("cos1","sin1","cos2","sin2")}

mu <- function(p,linear) exp(linear)
gnlr(resp,"gamma",mu=mu,linear=~1,pmu=5,psh=3)
gnlr(resp,"gamma",mu=mu,linear=~trend,pmu=c(5,0),psh=3)
gnlr(resp,"gamma",mu=mu,linear=~cos1+sin1,pmu=c(5,0,0),psh=3.6)
gnlr(resp,"gamma",mu=mu,linear=~cos1+sin1+cos2+sin2,pmu=c(5,0,0,0,0),psh=3.6)
gnlr(resp,"Weibull",mu=mu,linear=~1,pmu=5,psh=3)
gnlr(resp,"Weibull",mu=mu,linear=~trend,pmu=c(5,0),psh=3)
gnlr(resp,"Weibull",mu=mu,linear=~cos1+sin1,pmu=c(5,0,0),psh=3.6)
gnlr(resp,"Weibull",mu=mu,linear=~cos1+sin1+cos2+sin2,pmu=c(5,0,0,0,0),psh=3.6)

kalseries(resp,intensity="Weibull",preg=4.7,pinit=1,psh=1,link="log")
kalseries(resp,intensity="Weibull",preg=4.7,pinit=1,psh=1,link="log",
	dep="frailty")
kalseries(resp,intensity="Weibull",preg=4.7,pinit=1,psh=1,link="log",
	dep="serial",pdep=0.5)
kalseries(resp,intensity="Weibull",preg=4.5,pinit=1,psh=1,link="log",
	tvcov=tvc2,ptvc=c(0.02,0.3,0.2,0.08))
kalseries(resp,intensity="Weibull",preg=4.5,pinit=1,psh=1,link="log",
	dep="frailty",tvcov=tvc2,ptvc=c(0.02,0.3,0.2,0.08))
print(z <- kalseries(resp,intensity="Weibull",preg=4.5,pinit=2,
	psh=1,link="log",dep="serial",pdep=0.6,tvcov=tvc2,
	ptvc=c(0.02,0.3,0.2,0.08)))

kalseries(resp,intensity="normal",preg=120,pinit=0.5,psh=200)
kalseries(resp,intensity="normal",preg=120,pinit=0.1,psh=200,dep="frailty")
kalseries(resp,intensity="normal",preg=120,pinit=1,psh=200,
	dep="serial",pdep=0.5)
kalseries(resp,intensity="normal",preg=112,pinit=2,psh=140,
	dep="serial",pdep=0.6,tvcov=tvc2,ptvc=c(0.03,3,3.4,-4.6))

kalseries(resp,intensity="gamma",preg=2,pinit=0.5,psh=1,link="log")
kalseries(resp,intensity="gamma",preg=4.7,pinit=0.1,psh=5,
	link="log",dep="frailty")
kalseries(resp,intensity="gamma",preg=4.7,pinit=1,psh=3,
	link="log",dep="serial",pdep=0.4)
kalseries(resp,intensity="gamma",preg=4.5,pinit=2,psh=1,link="log",
	dep="serial",pdep=0.6,tvcov=tvc2,ptvc=c(0.02,0.3,0.2,0.08))

if(interactive()){
tt <- 8:21
#postscript("plasma.eps",width=5)
par(mfrow=c(2,1))
plot(tt,y[1,],pch=1,ylim=c(0,200),xlim=c(7,22),
	ylab="Plasma citrate concentration",xlab="")
for(i in 2:5)points(tt,y[i,],pch=i)
lines(tt,exp(4.52511+0.01776*cos(2*pi*(8:21)/24)+0.25566*sin(2*pi*(8:21)/24)+
	0.15169*cos(2*pi*(8:21)/12)+0.07742*sin(2*pi*(8:21)/12)))
plot(tt,y[6,],pch=6,ylim=c(0,200),xlim=c(7,22),
	ylab="Plasma citrate concentration",xlab="Hour")
for(i in 7:10)points(tt,y[i,],pch=i)
lines(tt,exp(4.52511+0.01776*cos(2*pi*(8:21)/24)+0.25566*sin(2*pi*(8:21)/24)+
	0.15169*cos(2*pi*(8:21)/12)+0.07742*sin(2*pi*(8:21)/12)))
}
if(interactive()){
postscript("plasma.eps")
par(mfrow=c(3,2),font.main=1)
plot(mprofile(z),ylim=c(0,200),ylab="Plasma citrate concentration",
	xlab="Hour",main="Individuals 1 and 2")
plot(iprofile(z),add=T,lty=2,pch=0)
plot(iprofile(z),add=T,lty=3,pch=1,nind=2)
plot(mprofile(z),ylim=c(0,200),ylab="",xlab="Hour",
	main="Individuals 3 and 4")
plot(iprofile(z),add=T,lty=2,pch=0,nind=3)
plot(iprofile(z),add=T,lty=3,pch=1,nind=4)
plot(mprofile(z),ylim=c(0,200),ylab="Plasma citrate concentration",
	xlab="Hour",main="Individuals 5 and 6")
plot(iprofile(z),add=T,lty=2,pch=0,nind=5)
plot(iprofile(z),add=T,lty=3,pch=1,nind=6)
plot(mprofile(z),ylim=c(0,200),ylab="",xlab="Hour",
	main="Individuals 7 and 8")
plot(iprofile(z),add=T,lty=2,pch=0,nind=7)
plot(iprofile(z),add=T,lty=3,pch=1,nind=8)
plot(mprofile(z),ylim=c(0,200),ylab="Plasma citrate concentration",
	xlab="Hour",main="Individuals 9 and 10")
plot(iprofile(z),add=T,lty=2,pch=0,nind=9)
plot(iprofile(z),add=T,lty=3,pch=1,nind=10)
}
