library(gnlm)

data <- read.table("rpe.dat",skip=2,head=T)
attach(data)
sex <- as.factor(NR>6)
sx <- NR>6
wt <- RPE>0
rpe <- RPE
rpe[wt==0] <- 1
rpe1 <- ifelse(T>6,c(1,log(rpe[1:51])),0)
lt <- log(T)
tmp <-  diff(T)
lt[T>6] <- log(tmp[tmp>0])
nr <- as.factor(NR)
gm <- T==6

if(interactive()){
postscript("rpe.eps",height=5)
par(mfrow=c(1,2),font.main=1)
plot(T[1:4],RPE[1:4],xlim=c(0,40),ylim=c(0,20),xlab="Minutes",
	ylab="Rate of perceived exertion",main="Female",type="l")
lines(T[1:4],RPE[5:8])
lines(T[1:4],RPE[9:12])
lines(T[1:4],RPE[13:16])
lines(T[1:4],RPE[17:20])
lines(T[1:3],RPE[21:23])
plot(T[1:3],RPE[25:27],xlim=c(0,40),ylim=c(0,20),xlab="Minutes",
	ylab="Rate of perceived exertion",main="Male",type="l")
lines(T[1:4],RPE[29:32])
lines(T[1:3],RPE[33:35])
lines(T[1:4],RPE[37:40])
lines(T[1:3],RPE[41:43])
lines(T[1:3],RPE[45:47])
lines(T[1:3],RPE[49:51])
}

# independence
mu <- function(p,linear) exp(linear)
gnlr(rpe,"gamma",wt=wt,mu=mu,linear=~1,pmu=2.5,psh=1)
gnlr(rpe,"gamma",wt=wt,mu=mu,linear=~sex,pmu=c(2.5,0),psh=3.6)

# Jorgensen models
glm(rpe~lt:nr-1+nr:gm,weights=wt*exp(rpe1),offset=rpe1,family=Gamma(link=log))
glm(rpe~lt:sex-1+nr:gm,weights=wt*exp(rpe1),offset=rpe1,family=Gamma(link=log))
glm(rpe~lt-1+nr:gm,weights=wt*exp(rpe1),offset=rpe1,family=Gamma(link=log))
1.877/32
glm(rpe~lt-1+gm,weights=wt*exp(rpe1),offset=rpe1,family=Gamma(link=log))
glm(rpe~gm:sex-1,weights=wt*exp(rpe1)*(T==6),offset=rpe1+0.05088*lt,
	family=Gamma(link=log))
0.205/11
0.205/11/(1.877/32)
glm(rpe~gm-1,weights=wt*exp(rpe1)*(T==6),offset=rpe1+0.05088*lt,
	family=Gamma(link=log))


mu <- function(p,linear) exp(rpe1+linear)
shape <- function(p) p[1]*rpe1
gnlr(rpe,"gamma",wt=wt,mu=mu,linear=~lt:nr+nr:gm-1,shape=shape,
	pmu=c(rep(0.05,13),rep(2.2,13)),psh=2)
gnlr(rpe,"gamma",wt=wt,mu=mu,linear=~lt:sex-1+nr:gm,shape=shape,
	pmu=c(0.06,0.04,rep(2.2,13)),psh=2)
gnlr(rpe,"gamma",wt=wt,mu=mu,linear=~lt-1+nr:gm,shape=shape,
	pmu=c(0.05,rep(2.5,13)),psh=2)
gnlr(rpe,"gamma",wt=wt,mu=mu,linear=~lt-1,shape=shape,
	pmu=c(0.05),psh=2)
gnlr(rpe,"gamma",wt=wt,mu=mu,linear=~lt-1+gm,shape=shape,
	pmu=c(0.05,2.5),psh=2)
gnlr(rpe,"gamma",wt=wt,mu=mu,linear=~lt:sex-1+gm,shape=shape,
	pmu=c(0.05,0.05,2.5),psh=2)
gnlr(rpe,"gamma",wt=wt,mu=mu,linear=~lt-1+gm,shape=shape,pmu=c(0.05,2.5),psh=2)

mum <- function(p,linear) exp(0.04801*lt+linear)
gnlr(rpe,"gamma",wt=wt*(T==6),mu=mum,linear=~gm:sex-1,pmu=c(2.3,2.3),psh=4)
gnlr(rpe,"gamma",wt=wt*(T==6),mu=mum,linear=~gm-1,pmu=2.3,psh=4)
exp(-4.152+2.195)
exp(-4.152)

mu <- function(p) exp(p[1]*(T==6)+(p[2]+p[3]*rpe1)*(T>6)+p[4]*lt)
shape <- function(p) p[1]*(T==6)+rpe1*p[2]
gnlr(rpe,"gamma",wt=wt,mu=mu,shape=shape,pmu=c(2.5,2.5,0,0),psh=c(3.6,0))
mu <- function(p) exp(p[1]*(T==6)+(p[2]+p[3]*rpe1)*(T>6)+p[4]*lt+p[5]*sx)
gnlr(rpe,"gamma",wt=wt,mu=mu,shape=shape,pmu=c(2.4,0.8,0.7,0.04,0),
	psh=c(3.6,2))
mu <- function(p) exp(p[1]*(T==6)+(p[2]+p[3]*rpe1)*(T>6)+p[4]*lt
	+p[5]*sx*(T==6))
gnlr(rpe,"gamma",wt=wt,mu=mu,shape=shape,pmu=c(2.5,0.8,0.7,0.04,0),
	psh=c(3.6,2))
exp(-4.152+2.438)
#VO2  HR   LACT   VE   VEVO
mu <- function(p) exp(p[1]*(T==6)+(p[2]+p[3]*rpe1)*(T>6)+p[4]*sx*(T==6)+
	p[5]*lt+p[6]*VO2)
gnlr(rpe,"gamma",wt=wt,mu=mu,shape=shape,pmu=c(2.3,0.8,0.7,0.2,0.03,-0.003),
	psh=c(4.2,2.4))
mu <- function(p) exp(p[1]*(T==6)+(p[2]+p[3]*rpe1)*(T>6)+p[4]*sx*(T==6)+
	p[5]*lt+p[6]*HR)
gnlr(rpe,"gamma",wt=wt,mu=mu,shape=shape,pmu=c(2.3,0.8,0.7,0.2,0.03,-0.0004),
	psh=c(4.2,2.4))
mu <- function(p) exp(p[1]*(T==6)+(p[2]+p[3]*rpe1)*(T>6)+p[4]*sx*(T==6)+
	p[5]*lt+p[6]*LACT)
gnlr(rpe,"gamma",wt=wt,mu=mu,shape=shape,pmu=c(2.3,0.8,0.7,0.2,0.03,0.0015),
	psh=c(4.2,2.4))
mu <- function(p) exp(p[1]*(T==6)+(p[2]+p[3]*rpe1)*(T>6)+p[4]*sx*(T==6)+
	p[5]*lt+p[6]*VE)
gnlr(rpe,"gamma",wt=wt,mu=mu,shape=shape,pmu=c(2.3,0.8,0.7,0.2,0.03,-0.0004),
	psh=c(4.2,2.4))
mu <- function(p) exp(p[1]*(T==6)+(p[2]+p[3]*rpe1)*(T>6)+p[4]*sx*(T==6)+
	p[5]*lt+p[6]*VEVO)
gnlr(rpe,"gamma",wt=wt,mu=mu,shape=shape,pmu=c(2.3,0.8,0.7,0.2,0.03,-0.0004),
	psh=c(4.2,2.4))
mu <- function(p) exp(p[1]*(T==6)+(p[2]+p[3]*rpe1)*(T>6)+p[4]*sx*(T==6)+
	p[5]*lt+p[6]*VO2+p[7]*VEVO)
gnlr(rpe,"gamma",wt=wt,mu=mu,shape=shape,pmu=c(2.3,0.8,0.7,0.2,0.03,
	-0.003,-0.0004),psh=c(4,2.5),iter=200)
exp(-4.127+2.586)
