library(repeated)
library(gnlm)

data <- as.matrix(read.table("chicks.dat",skip=4))
times <- c(seq(0,20,by=2),21)
y <- restovec(data,times=times)
trt <- c(rep(1,20),rep(2,10),rep(3,10),rep(4,10))
trt2 <- c(rep(1,20),rep(2,30))
x <- cbind(trt,trt2)
colnames(x) <- c("trt","trt2")
x1 <- tcctomat(x)
timem <- matrix(rep(times,50),ncol=12,byrow=T)
x2 <- tvctomat(timem)
resp <- rmna(y,tvcov=x2,ccov=x1)

trtv <- trt[rep(1:length(resp$resp$nobs),resp$resp$nobs)]
trt2v <- trt2[rep(1:length(resp$resp$nobs),resp$resp$nobs)]
timev <- as.vector(resp$tvc$tvc)
trt <-  as.factor(trt)

mu0 <- function(p) p[1]+p[2]*(trt2v==2)
mu1 <- function(p) p[1]+(p[2]*(trt2v==2)+p[3])*timev
#mu1a <- function(p) p[1]+p[2]*(timev-10.71799)
mu2 <- function(p) p[1]+(p[2]*(trt2v==2)+p[3]+p[4]*timev)*timev
mu3 <- function(p) p[1]+(p[2]*(trtv==2)+p[3]*(trtv==3)+
	p[4]*(trtv==4)+p[5]+p[6]*timev)*timev
mu4 <- function(p) p[1]+(p[2]*(trtv==2)+p[2]*(trtv==3)+
	p[3]*(trtv==4)+p[4]+p[5]*timev)*timev

y <- resp$resp$y
#gnlr(y,"Weibull",mu=mu1a,pmu=c(150,1),psh=1)
gnlr(y,"Weibull",mu=mu1,pmu=c(150,20,1),psh=1)
gnlr(y,"Weibull",mu=mu2,pmu=c(42,-1,4,0.5),psh=2)

kalseries(data,times=times,preg=1)
kalseries(data,times=times,preg=120,dep="Markov",pdep=0.1,pinit=1)
kalseries(data,times=times,ccov=~trt,preg=c(110,20,20,20),
	dep="Markov",pinit=0.1,pdep=0.7)
kalseries(data,times=times,ccov=~trt2,preg=c(110,20),
	dep="Markov",pinit=0.1,pdep=0.7)

kalseries(data,times=times,intens="Weibull",ccov=~trt2,preg=c(110,20),
	dep="Markov",pinit=2,pdep=0.3,psh=1)
kalseries(data,times=times,intens="gamma",ccov=~trt2,preg=c(5,0.5),
	dep="Markov",pinit=6,pdep=0.66,psh=20)
kalseries(data,times=times,intens="log normal",ccov=~trt2,preg=c(10,0),
	dep="Markov",pinit=2,pdep=0.3,psh=0.6)

kalseries(data,times=times,intens="Weibull",ccov=~trt2,preg=c(110,20,0),
	dep="Markov",torder=1,pinit=2,pdep=0.3,psh=1)
#kalseries(data,times=times,intens="Weibull",ccov=~trt2,preg=c(110,20),
#	dep="Markov",tvcov=timem,ptv=0,pinit=2,pdep=0.3,psh=1)
kalseries(data,times=times,intens="Weibull",ccov=~trt2,preg=c(70,-10,0,0),
	dep="Markov",torder=2,pinit=2,pdep=0.3,psh=1)

kalseries(data,times=times,intens="Weibull",mu=mu1,
	dep="Markov",ptv=c(30,0,3),pinit=1,pdep=0.3,psh=1)
kalseries(data,times=times,intens="Weibull",mu=mu2,
	dep="Markov",ptv=c(37,7,4,0.3),pinit=2,pdep=0.3,psh=1)
kalseries(data,times=times,intens="Weibull",mu=mu3,
	dep="Markov",ptv=c(37,7,7,7,4,0.3),pinit=2,pdep=0.3,psh=1)
#kalseries(data,times=times,intens="gamma",mu=mu2,
#	dep="Markov",ptv=c(27,7,4,0.3),pinit=2,pdep=0.3,psh=2)
kalseries(data,times=times,intens="log normal",mu=mu2,
	dep="Markov",ptv=c(12,0.1,0.1,0),pinit=0.1,pdep=0.01,psh=10)

#kalseries(data,times=times,intens="Weibull",mu=mu1a,
#	dep="Markov",ptv=c(68,3),pinit=1,pdep=0.3,psh=1)
#kalseries(data,times=times,intens="Weibull",preg=c(110,0),
#	dep="Markov",torder=1,pinit=2,pdep=0.3,psh=1)

kalseries(data,times=times,intens="Weibull",ccov=~trt2,preg=c(110,20),
	dep="serial",pinit=2,pdep=0.3,psh=1)

gar(data,"Weibull",times=times,mu=mu0,preg=c(150,20),pdep=0.1,psh=1)
gar(data,"Weibull",times=times,mu=mu1,preg=c(150,20,1),pdep=0.1,psh=2)
print(g2 <- gar(data,"Weibull",times=times,mu=mu2,
	preg=c(40,-1,4,0.5),pdep=1,psh=2))
print(g3 <- gar(data,"Weibull",times=times,mu=mu3,
	preg=c(40,1,1,1,4,0.5),pdep=1,psh=2))
print(g4 <- gar(data,"Weibull",times=times,mu=mu4,
	preg=c(40,1,1,4,0.5),pdep=1,psh=2))
if(interactive()){
par(mfrow=c(2,2))
plot.iprofile(g4,nobs=1:3,lty=1:3,pch=1:3)
plot.iprofile(g4,nobs=21:23,lty=1:3,pch=1:3)
plot.iprofile(g4,nobs=31:33,lty=1:3,pch=1:3)
plot.iprofile(g4,nobs=41:43,lty=1:3,pch=1:3)
}
